mod fixtures;

#[macro_use]
mod macros;
mod argcfile;
mod cli;
mod complete_test;
mod escape_test;
mod fail_test;
mod help_tag_test;
mod main_fn_test;
mod spec_test;
